// ---------------------------------------------------------------------------
// packHUD.cs -- Version 1.3 -- December 9, 2000
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// Show the name and status of your current pack on the screen
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\packHUD.cs", "1.3", "Lorne Laliberte", "Dec 9, 2000");

include("writer\\event.cs");
include("writer\\inventory.cs");
include("writer\\item_events.cs");
include("writer\\save.cs");
include("writer\\scroller.cs");
include("writer\\weapon_switch.cs");
include("writer\\whatif.cs");
include("writer\\whud.cs");
include("writer\\you_died.cs");
include("writer\\you_respawned.cs");
include("writer\\you_spawned.cs");

// ---------------------------------------------------------------------------
// DEFAULT SETTINGS:
//
// Edit these if you're running this script for the first time
// All subsequent settings must be done in the config\wp_packHUD.cs file

    // Screen coordinates for packHUD
    $packHUD::X = "0%";
    $packHUD::Y = "100%";

    // Default colour to use (0 = brown, 1 = light tan, 2 = white)
    $packHUD::Colour = "1";

    // Colour to use when packs are active (0 = brown, 1 = light tan, 2 = white)
    $packHUD::Hilite = "2";

    // Make the packHUD background transparent
    $packHUD::Transparent = "false";

    // Enable packHUD by default
    $packHUD::visible = "true";

    // Width of the hud in pixels -- make sure it's wide enough for the text!
    $packHUD::width = "150";

    // Toggle packHUD on/off
    //bind(keyboard0, make, alt, "whatever", TO, "packHUD::toggle();");
    //bind(keyboard0, break, alt, whatever, TO, "", packHUD::toggle_break);

// ---------------------------------------------------------------------------

WriterPrefs::load("packHUD");

$packHUD::height=18;

function packHUD::toggle()
{
    if($packHUD::visible = !$packHUD::visible)
        wHUD::show(packHUD);
    else
        wHUD::hide(packHUD);
}


function packHUD::setup()
{
    if($packHUD::transparent)
    {
        $packHUD::ColourText[0] = "<f0>";
        $packHUD::ColourText[1] = "<f1>";
        $packHUD::ColourText[2] = "<f2>";
    }
    else
    {
        $packHUD::ColourText[0] = "<f0><jc>";
        $packHUD::ColourText[1] = "<f1><jc>";
        $packHUD::ColourText[2] = "<f2><jc>";
    }
}


function packHUD::update(%text, %colour)
{
    if(%text == "")
        %text = $Inv::Name[getMountedItem(1)];

    if(%colour == "")
        %colour = wif($packHUD::using, $packHUD::Hilite, $packHUD::Colour);

    $packHUD::currentText = %text;

    wHUD::update(packHUD, $packHUD::ColourText[%colour] @ %text);
}


function packHUD::onPackOn(%itemtype, %itemname)
{
    $packHUD::using = true;
    $packHUD::currentText = %itemname;

    packHUD::update(%itemname, $packHUD::Hilite);
    return;
}


function packHUD::onPackOff(%itemtype, %itemname)
{
    $packHUD::using = false;

    packHUD::update(%itemname, $packHUD::Colour);
    return;
}


function packHUD::onDropped(%itemtype, %itemname)
{
    if($Inv::isPack[%itemtype])
    {
        $packHUD::using = false;
        $packHUD::currentText = "";
    
        wHUD::update(packHUD, "");
    }
    return;
}

function packHUD::onYouSpawned()
{
    if(!wHUD::exists(packHUD))
    {
        packHUD::setup();

        // Build packHUD on first weapon switch, after playGui exists
        wHUD::makeMoveable(1, 1, 0, packHUD, $packHUD::x, $packHUD::y, $packHUD::width, $packHUD::height, $packHUD::transparent, $packHUD::visible, "");

        $packHUD::using = false;
        packHUD::update();
    }
    else
    {
        packHUD::show();
    }
    return;
}


function packHUD::relocate()
{
    wHUD::makeMoveable(1, 1, 0, packHUD, $packHUD::x, $packHUD::y, $packHUD::width, $packHUD::height, $packHUD::transparent, $packHUD::visible, $packHUD::currentText);
    return;
}

function packHUD::onWeaponSwitch(%weapon, %fromWeapon)
{
    if(%fromWeapon == $Inv::Repair_Gun)
    {
        $packHUD::using = false;
        packHUD::update($packHUD::currentText, $packHUD::Colour);
    }
    return;
}

function packHUD::onDeployed(%itemtype, %itemname)
{
    $packHUD::using = false;
    $packHUD::currentText = "";

    wHUD::update(packHUD, "");
    return;
}


function packHUD::onBuy(%itemtype, %itemname)
{
    if($Station::AtStation)
    {
        $packHUD::using=false;
        if($Inv::isPack[%itemtype])
        {
            schedule("packHUD::update();", 0.1);
            schedule("packHUD::update();", 0.5);
        }
    }
    return;
}


function packHUD::onBuyFavorites()
{
    if($Station::AtStation)
    {
        $packHUD::using=false;
        schedule("packHUD::update();", 0.1);
        schedule("packHUD::update();", 0.5);
    }
    return;
}


function packHUD::onExitStation()
{
    packHUD::update();
    return;
}

function packHUD::onServerMessage(%msg, %repeated)
{
    if(String::findSubStr(%msg, "You received ") != -1)
    {
        schedule("packHUD::update();", 0.1);
        schedule("packHUD::update();", 0.5);
    }
    return;
}


function packHUD::onChangeMission()
{
    $packHUD::currentText = "";
    wHUD::update(packHUD, "");
    wHUD::hide(packHUD);
    return;
}


function onHudMove_packHUD(%x, %y, %width, %height)
{
    $packHUD::x = %x;
    $packHUD::y = %y;
    $packHUD::width = %width;
    wHUD::make(packHUD, $packHUD::x, $packHUD::y, $packHUD::width, $packHUD::height, $packHUD::transparent, 1, $packHUD::currentText);
    return;
}


function packHUD::onYouDied()
{
    if(wHUD::exists(packHUD))
        Scroller::start(packHUD, "                  packHUD 1.1 by Lorne Laliberte (Writer), hope you enjoy this nifty little HUD. :)        ,+'`'+._,+'`'+._,+'`'+._,+'`'+._,+'`'+.", 18, 0.1, $weaponHUD::ColourText[$weaponHUD::Colour]);

    return;
}


function packHUD::onYouRespawned()
{
    scroller::stop(packHUD);

    packHUD::show();
    return;
}


function packHUD::show()
{
    packHUD::update();
    if($packHUD::visible)
        wHUD::show(packHUD);

    return;
}


function packHUD::hide()
{
    wHUD::hide(packHUD);
    return;
}

function packHUD::save()
{
    AddExportText("    // Screen coordinates for packHUD");
    ExportSetting("    $packHUD::X", "0%");
    ExportSetting("    $packHUD::Y", "100%");
    AddExportText("");
    AddExportText("    // Default colour to use (0 = brown, 1 = light tan, 2 = white)");
    ExportSetting("    $packHUD::Colour", 1);
    AddExportText("");
    AddExportText("    // Colour to use when packs are active (0 = brown, 1 = light tan, 2 = white)");
    ExportSetting("    $packHUD::Hilite", 2);
    AddExportText("");
    AddExportText("    // Make the packHUD background transparent");
    ExportSetting("    $packHUD::Transparent", false);
    AddExportText("");
    AddExportText("    // Enable packHUD by default");
    ExportSetting("    $packHUD::visible", true);
    AddExportText("");
    AddExportText("    // Width of the hud in pixels -- make sure it's wide enough for the text!");
    ExportSetting("    $packHUD::width", 150);
    AddExportText("");
    AddExportText("    // Toggle packHUD on/off");

    ExportBind("packHUD::toggle();", "//bind(keyboard0, make, alt, \"whatever\", TO, \"packHUD::toggle();\");");
    ExportBind("packHUD::toggle_break", "//bind(keyboard0, break, alt, whatever, TO, \"\", packHUD::toggle_break);");
}

WriterPrefs::save("packHUD");

function packHUD::init()
{
    needs("writer\\packHUD.cs", "writer\\event.cs 2.7",
                                "writer\\inventory.cs 3.3",
                                "writer\\item_events.cs 2.12",
                                "writer\\save.cs 2.3",
                                "writer\\scroller.cs 1.1",
                                "writer\\weapon_switch.cs 2.5",
                                "writer\\whatif.cs 1.1",
                                "writer\\whud.cs 1.2",
                                "writer\\you_died.cs 1.6",
                                "writer\\you_respawned.cs 1.2",
                                "writer\\you_spawned.cs 1.1");

    Event::Attach(eventDeployed, packHUD::onDeployed);
    Event::Attach(eventDropped, packHUD::onDropped);
    Event::Attach(eventEnterCommandStation, "packHUD::hide();");
    Event::Attach(eventExitCommandStation, "packHUD::hide();");
    Event::Attach(eventPackOn, packHUD::onPackOn);
    Event::Attach(eventPackOff, packHUD::onPackOff);
    Event::Attach(eventPilotModeOn, "packHUD::hide();");
    Event::Attach(eventPilotModeOff, "packHUD::show();");
    Event::Attach(eventYouDied, packHUD::onYouDied);
    Event::Attach(eventBuy, packHUD::onBuy);
    Event::Attach(eventBuyFavorites, "packHUD::onBuyFavorites();");
    Event::Attach(eventExitStation, packHUD::onExitStation);
    Event::Attach(eventWeaponSwitch, packHUD::onWeaponSwitch);
    Event::Attach(eventServerMessage, packHUD::onServerMessage);
    Event::Attach(eventChangeMission, "packHUD::onChangeMission();");
    Event::Attach(eventConnected, "packHUD::onChangeMission();");
    Event::Attach(eventYouRespawned, "packHUD::onYouRespawned();");
    Event::Attach(eventYouSpawned, "packHUD::onYouSpawned();");
    Event::Attach(eventScreenModeChanged, "packHUD::relocate();");
    Event::Attach(eventScreenSizeChanged, "packHUD::relocate();");
    Event::Attach(wHudMove_packHUD, onHudMove_packHUD);
    Event::Attach(wHudSave_packHUD, "WriterPrefs::save(\"packHUD\");");
}
Event::Attach(writerInit, "packHUD::init();");

if(!$UsingWriterLoader) packHUD::init();
